@@ -1,4 +1,12 @@
-from .constants.repo_paths import *
+from .constants.repo_paths import (
+    DIRECTORY_WITH_DATA,
+    DIRECTORY_WITH_GRAPHS_IMAGES,
+    DIRECTORY_WITH_SAVED_MODELS,
+    ORIGINAL_RUSSIAN_DF_NAME,
+    CLEANED_RUSSIAN_DF_NAME,
+    ORIGINAL_ENGLISH_DF_NAME,
+    TRANSLATED_CLEANED_ENGLISH_DF_NAME
+)
 from .constants.aliases import *
 from .constants.default_hyperparameters import *
 from .constants.graphs_style_params import *
